@@ -37,7 +37,6 @@ for one or more target platforms using a C/C++ cross compiler::
 	top = '.'
 	out = 'build'
 	prefix = 'output'
-	ccrossini = os.path.abspath('ccross.ini').replace('\\', '/')
 
 	VERSION = '0.0.1'
 	APPNAME = 'cross-test'
@@ -53,7 +52,7 @@ for one or more target platforms using a C/C++ cross compiler::
 	def build(bld):
 		ccross.build(bld, trees=['components'])
 
-	for var in ccross.variants(ccrossini):
+	for var in ccross.variants():
 		for ctx in ccross.contexts():
 			name = ctx.__name__.replace('Context','').lower()
 			class _t(ctx):
@@ -89,6 +88,7 @@ of that tree.
 '''
 
 import os
+import sys
 try:
 	import ConfigParser as configparser
 except:
@@ -102,9 +102,18 @@ from waftools.makefile import MakeFileContext
 from waftools.eclipse import EclipseContext
 
 
+CCROSS_INI='ccross.ini'
+CCROSS_ARG='--ccross'
+CCROSS_OPT='ccross'
+
+
 def options(opt):
 	opt.add_option('--all', dest='all', default=False, action='store_true', 
 				help='execute command for cross-compile environments as well')
+
+	opt.add_option(CCROSS_ARG, dest=CCROSS_OPT, default=CCROSS_INI, action='store', 
+				help='cross compile configuration')
+
 	opt.load('cmake', tooldir=waftools.location)
 	opt.load('codeblocks', tooldir=waftools.location)
 	opt.load('cppcheck', tooldir=waftools.location)
@@ -118,55 +127,16 @@ def options(opt):
 	opt.load('indent', tooldir=waftools.location)
 
 
-def config_base(conf):
-	v = Context.WAFVERSION
-	try:
-		conf.load('compiler_c unity')
-		conf.load('compiler_cxx unity')
-		conf.load('batched_cc')
-	except Errors.ConfigurationError as e:
-		# retry configuration without unity,batched_cc
-		conf.load('compiler_c')
-		conf.load('compiler_cxx')
-	conf.load('cppcheck')
-	conf.load('codeblocks')
-	conf.load('eclipse')
-	conf.load('gnucc')
-	conf.load('makefile')
-	conf.load('msdev')
-	conf.load('tree')
-
-
 def configure(conf):
 	conf.check_waf_version(mini='1.7.6', maxi='1.8.9')
-	prefix = str(conf.env.PREFIX).replace('\\', '/')
-	cross = get_config(conf.env.CCROSSINI)
-
-	for name, ini in cross.items(): # setup cross compile environment(s)
-		conf.setenv(name)
-		conf.env.CCROSS = cross
-		conf.env.PREFIX = '%s/opt/%s' % (prefix, name)
-		conf.env.BINDIR = '%s/opt/%s/bin' % (prefix, name)
-		conf.env.LIBDIR = '%s/opt/%s/lib' % (prefix, name)
-		
-		pre = ini['prefix']
-		conf.find_program('%s-gcc' % (pre), var='CC')
-		
-		for ext in ('gxx','g++','c++'):
-			cxx = '%s-%s' % (pre, ext)
-			try:
-				conf.find_program(cxx, var='CXX')
-			except Errors.ConfigurationError as e:
-				Logs.debug("program '%s' not found" % (cxx))
-			else:
-				break
-		
-		conf.find_program('%s-ar' % (pre), var='AR')
-		config_base(conf)
+	
+	conf.env.PREFIX = str(conf.env.PREFIX).replace('\\', '/')
+	conf.env.CCROSSINI = getattr(conf.options, CCROSS_OPT)
+	conf.env.CCROSS = _get_config(conf.env.CCROSSINI)
+	_config_cross(conf)
 
 	conf.setenv('')
-	conf.env.CCROSS = cross
-	config_base(conf)
+	_config_base(conf)
 	conf.load('cmake')
 	conf.load('doxygen')
 	conf.load('package')
@@ -189,33 +159,98 @@ def build(bld, trees=[]):
 			bld.recurse(script)
 
 
-def get_config(name):
+def _config_base(conf):
+	v = Context.WAFVERSION
+	try:
+		conf.load('compiler_c unity')
+		conf.load('compiler_cxx unity')
+		conf.load('batched_cc')
+	except Errors.ConfigurationError as e: # retry without unity,batched_cc
+		conf.load('compiler_c')
+		conf.load('compiler_cxx')
+	conf.load('cppcheck')
+	conf.load('codeblocks')
+	conf.load('eclipse')
+	conf.load('gnucc')
+	conf.load('makefile')
+	conf.load('msdev')
+	conf.load('tree')
+
+
+def _config_cross(conf):
+	'''create and configure cross compile environments
+
+ 	uses the the configuration data as specified in the *.ini
+	file using configparser.ExtendedInterpolation syntax.
+	'''
+	prefix = conf.env.PREFIX
+	ccross = conf.env.CCROSS
+
+	for name, ini in ccross.items(): # setup cross compile environment(s)
+		conf.setenv(name)
+		conf.env.PREFIX = '%s/opt/%s' % (prefix, name)
+		conf.env.BINDIR = '%s/opt/%s/bin' % (prefix, name)
+		conf.env.LIBDIR = '%s/opt/%s/lib' % (prefix, name)
+		
+		for (var, action, value) in ini['env']:
+			if action == 'set':
+				conf.env[var] = value
+			else:
+				conf.env.append_unique(var, value)	
+
+		pre = ini['prefix']
+		conf.find_program('%s-gcc' % (pre), var='CC')
+		
+		for ext in ('gxx','g++','c++'):
+			cxx = '%s-%s' % (pre, ext)
+			try:
+				conf.find_program(cxx, var='CXX')
+			except Errors.ConfigurationError as e:
+				Logs.debug("program '%s' not found" % (cxx))
+			else:
+
+				break
+		
+		conf.find_program('%s-ar' % (pre), var='AR')
+		_config_base(conf)
+
+
+def _get_config(name):
 	'''Returns dictionary of cross-compile build environments. Dictionary key name
 	depict the environment name (i.e. variant name).
+
 	
 	:param name: Complete path to the config.ini file
 	:type name: str
 	'''
 	if not os.path.exists(name):
-		return {}
+		Logs.warn("CCROSS: ini file '%s' not found!" % name)
 	cross = {}
 	c = configparser.ConfigParser()
 	c.read(name)
 	for s in c.sections():
 		cross[s] = {}
 		cross[s]['prefix'] = c.get(s,'prefix')
-		cross[s]['shlib'] = [l for l in str(c.get(s,'shlib')).split(',') if not l == ''] 
+		cross[s]['shlib'] = [l for l in str(c.get(s,'shlib')).split(',') if len(l)]
+		cross[s]['env'] = [l.split('\t') for l in c.get(s,'env').splitlines() if len(l)]
 	return cross
 
 
-def variants(name):
+def variants(name=None):
 	'''Returns a list of variant names; i.e. a list of names for build environments 
 	that have been defined in the 'ccross.ini' configuration file.
 	
 	:param name: Complete path to the config.ini file
 	:type name: str
 	'''
-	cross = get_config(name)
+	if not name:
+		name = CCROSS_INI
+		opt = '%s=' % CCROSS_ARG
+		for a in sys.argv:
+			if a.startswith(opt):
+				name = a.replace(opt, '')
+
+	cross = _get_config(name)
 	return list(cross.keys())
 
 
