@@ -14,8 +14,8 @@ See https://www.eclipse.org and https://www.eclipse.org/cdt for a more detailed
 description on how to install and use it for your particular Desktop environment.
 
 .. note::
-	Export of C/C++ projects are supported for GCC/MinGW compilers only, 
-	other compilers and/or environments (e.g. MSVC, CygWin) are NOT supported!
+    Export of C/C++ projects are supported for GCC/MinGW compilers only, 
+    other compilers and/or environments (e.g. MSVC, CygWin) are NOT supported!
 
 Description
 -----------
@@ -49,8 +49,8 @@ projects already have been exported::
 
 
 .. warning:: 
-	Export of multiple C/C++ build tasks (program, stlib and/or shlib) 
-	which have been defined within the same directory is not supported.
+    Export of multiple C/C++ build tasks (program, stlib and/or shlib) 
+    which have been defined within the same directory is not supported.
 
 Projects will be exported such that they will use the same settings and 
 structure as has been defined for that build task within the *waf* build 
@@ -422,7 +422,8 @@ class CDTProject(EclipseProject):
 			self.cdt['artifactExtension'] = 'a'
 
 		e = self.cdt['ext']
-		ar = os.path.splitext(os.path.basename(tgen.env.AR))[0]
+		ar = Utils.to_list(tgen.env.AR)[0]
+		ar = os.path.splitext(os.path.basename(ar))[0]
 		cc = tgen.env.CC[0]
 		self.cdt['c'] = os.path.splitext(os.path.basename(cc))[0]
 		self.cdt['cpp'] = os.path.splitext(os.path.basename(tgen.env.CXX[0]))[0]
@@ -527,7 +528,7 @@ class CDTProject(EclipseProject):
 		scanner.set('instanceId', '%s;%s.;%s;%s' % (i, i, c, f))
 		ElementTree.SubElement(scanner, 'autodiscovery', {'enabled': 'true', 'problemReportingEnabled' : 'true', 'selectedProfileId' : ''})
 
-	def	cconfig_get(self, module):
+	def cconfig_get(self, module):
 		'''Returns configuration module'''
 		for cconfig in module.findall('cconfiguration'):
 			if cconfig.get('id') and cconfig.get('id').startswith(self.cdt['parent']):
@@ -537,7 +538,7 @@ class CDTProject(EclipseProject):
 							return cconfig
 		return None
 
-	def	cconfig_update(self, cconfig):
+	def cconfig_update(self, cconfig):
 		'''Update configuration module.'''
 		cconfig.set('id', self.cdt['instance'])
 		for storage in cconfig.findall('storageModule'):
@@ -546,7 +547,7 @@ class CDTProject(EclipseProject):
 			if storage.get('moduleId') == 'cdtBuildSystem':
 				self.cconfig_buildsystem_update(storage)
 
-	def	cconfig_settings_update(self, storage):
+	def cconfig_settings_update(self, storage):
 		storage.set('name', self.cdt['name'])
 		storage.set('id', self.cdt['instance'])
 
@@ -563,7 +564,7 @@ class CDTProject(EclipseProject):
 				if entry.get('kind') == 'libraryFile':
 					entry.set('name', '%s' % name)
 
-	def	cconfig_buildsystem_update(self, storage):
+	def cconfig_buildsystem_update(self, storage):
 		config = storage.find('configuration')
 		config.set('name', self.cdt['name'])
 		config.set('buildArtefactType', self.cdt['buildArtefactType'])
@@ -579,12 +580,12 @@ class CDTProject(EclipseProject):
 		folder.set('id','%s.' % (self.cdt['instance']))
 		self.cconfig_toolchain_update(folder)
 
-	def	cconfig_toolchain_update(self, folder):
+	def cconfig_toolchain_update(self, folder):
 		toolchain = folder.find('toolChain')
 		toolchain.set('superClass', self.cdt['toolchain'])
 		toolchain.set('id', '%s.%s' % (self.cdt['toolchain'], self.get_uuid()))
 		name = 'MinGW GCC' if sys.platform=='win32' else 'Linux GCC'
-		if self.cross and sys.platform!='win32':		
+		if self.cross and sys.platform!='win32':
 			name = 'Cross GCC'
 		toolchain.set('name', name)
 
@@ -750,14 +751,21 @@ class CDTProject(EclipseProject):
 		for use in uses:
 			try:
 				tg = self.bld.get_tgen_by_name(use)
-			except Errors.WafError:
+			except Errors.WafError as e:
 				pass
 			else:
 				includes = Utils.to_list(getattr(tg, 'export_includes', []))
-				includes = list(set([str(i).lstrip('./') for i in includes]))
+				sources = Utils.to_list(getattr(tg, 'source', []))
+				if not len(sources):
+					top = tg.path.abspath().replace('\\', '/')
+					includes = ['%s/%s' % (top, i) for i in includes if len(i)]
+				else:
+					includes = list(set([str(i).lstrip('./') for i in includes]))
+					includes = ['"${workspace_loc:/%s/%s}"' % (use, i) for i in includes if len(i)]
+					
 				for include in includes:
 					listoption = ElementTree.SubElement(option, 'listOptionValue', {'builtIn':'false'})
-					listoption.set('value', '"${workspace_loc:/%s/%s}"' % (use, include))
+					listoption.set('value', include)
 
 	def compiler_add_defines(self, compiler, language):
 		if self.language != language:
@@ -830,8 +838,14 @@ class CDTProject(EclipseProject):
 			except Errors.WafError:
 				pass
 			else:
+				name = tgen.get_name()
 				if set(('cstlib', 'cshlib','cxxstlib', 'cxxshlib')) & set(tgen.features):
-					libs.append(tgen.get_name())
+					libs.append((name,None))
+
+				elif 'fake_lib' in tgen.features:
+					paths = [p.replace('\\', '/') for p in tgen.lib_paths]
+					libs.append((name, paths))
+
 		return libs if len(libs) else None
 
 	def toolchain_linker_add_libs(self, linker, language):
@@ -841,7 +855,10 @@ class CDTProject(EclipseProject):
 		option = ElementTree.SubElement(linker, 'option', {'name':'Libraries (-l)', 'valueType':'libs'})
 		option.set('superClass', 'gnu.%s.link.option.libs' % (language))
 		option.set('id', '%s.%s' % (option.get('superClass'), self.get_uuid()))
-		for lib in libs:
+		for (lib, _) in libs:
+			listoption = ElementTree.SubElement(option, 'listOptionValue', {'builtIn':'false'})
+			listoption.set('value', lib)
+		for lib in getattr(self.tgen, 'lib', []):
 			listoption = ElementTree.SubElement(option, 'listOptionValue', {'builtIn':'false'})
 			listoption.set('value', lib)
 
@@ -852,9 +869,13 @@ class CDTProject(EclipseProject):
 		option = ElementTree.SubElement(linker, 'option', {'name':'Library search path (-L)', 'valueType':'libPaths'})
 		option.set('superClass', 'gnu.%s.link.option.paths' % (language))
 		option.set('id', '%s.%s' % (option.get('superClass'), self.get_uuid()))
-		for lib in libs:
+		for (lib, paths) in libs:
 			listoption = ElementTree.SubElement(option, 'listOptionValue', {'builtIn':'false'})
-			listoption.set('value', '"${workspace_loc:/%s/%s}"' % (lib, self.cdt['name']))
+			if not paths:
+				listoption.set('value', '"${workspace_loc:/%s/%s}"' % (lib, self.cdt['name']))
+			else:
+				for path in paths:
+					listoption.set('value', path)
 
 	def toolchain_linker_add_input(self, linker, language):
 		if self.language != language or self.cdt['ext'] == 'lib':
